#!/usr/bin/env node
// @ts-ignore
import { logger } from "@haulynx/cli-tools";
// @ts-ignore
import { Kafka } from "kafkajs";

const topics = [
  {
    topicName: "local_bus_iohaulynx_usxorder_event_json"
  }
];

const kafkaOptions = {
  clientId: "local-cuor-mission-creation-sync-client",
  brokers: ["localhost:9092"],
  requestTimeout: 10000,
  connectionTimeout: 15000,
  retry: { initialRetryTime: 500 }
};

/**
 * Copied this script from loads-service and edited some code to get it working. Connects to confluent
 * cloud and populates the topic / avro.
 */
async function runSyncLocalKafka() {
  const kafka = new Kafka(kafkaOptions);
  try {
    logger.info(`Connecting to admin...`);

    const admin = kafka.admin();
    await admin.connect();

    logger.info(`Checking if topics exist...`);

    logger.info(`${topics.map(ar => ar.topicName)}`);
    logger.info(`Checking if topics exist...`);

    // const allTopics = await admin.fetchTopicMetadata({topics: ["fake"]});
    // const topicMetas = await admin.fetchTopicMetadata({topics: topics.map(ar => ar.topicName)});
    const topicMetas = await admin.fetchTopicMetadata({topics: []});

    logger.info(`fetched if topics exist... ${topicMetas.topics.map(t => t.name)}`);


    const existingTopics = topicMetas.topics.map(t => t.name);
    const topicsToCreate = topics.filter(
        ({ topicName }) => !existingTopics.includes(topicName)
    );

    if (topicsToCreate.length > 0) {
      await admin.createTopics({
        timeout: 15000,
        topics: [
          ...topicsToCreate.map(({ topicName }) => ({
            topic: topicName,
            numPartitions: 1,
            replicationFactor: 1
          }))
        ]
      });

      logger.info(`Created new topic`);
    } else {
      logger.info(`Topics "${existingTopics}" already exists!`);
    }
    logger.info(`Local kafka is synced 🙌🏼`);

    process.exit(0);
  } catch (e) {
    logger.error(`Error syncing local kafka`, e);
  }
}

runSyncLocalKafka();
