import fetch, { Response } from "node-fetch";
import { GATEWAY_URL } from "../conifg";
import { getServiceToServiceToken } from "./AuthClient";
import { logger } from "../services";

class GraphqlClient {
  private baseUrl: string;
  private headers: {
      "Content-Type": string
  };

  constructor() {
    this.baseUrl = GATEWAY_URL;
    this.headers = {
      "Content-Type": "application/json"
    };
  }

  private async sendGraphqlRequest(name: string, query: string, variables: any): Promise<any> {
    const token = await getServiceToServiceToken();

    const options = {
      method: "post",
      timeout: 30000,
      headers: {
        ...this.headers,
        "Authorization": `Bearer ${token}`
      },
      body: JSON.stringify({ query, variables: JSON.stringify(variables) })
    };
    const response: Response = await fetch(this.baseUrl, options);
    const result = await response.json();

    if (response.status >= 400) {
      logger.error({
          message: "Received error during a GQL query",
          name,
          variables,
          query,
          response: JSON.stringify(result)
      });

      return {
        valid: false,
        reason: "Received error during a GQL query",
        error: result.errors && result.errors.length ? result.errors[0].message : "Unparsable Error. Look into error log"
      };
    }

    return result.data[name];
  }

  async validateMission(orderNumbers: string[]): Promise<any> {
    const query = `query ValidateMissions($missionBatchInput: [MissionCreateInput!]!) {
      validateMissions(missionBatchInput: $missionBatchInput) {
        valid
        missions {
          orders {
            orderNumber
            reason
            valid
          }
        }
      }
    }`;

    const variables = { missionBatchInput: { orderNumbers } };

    return this.sendGraphqlRequest("validateMissions", query, variables);
  }
}

export const graphqlClient = new GraphqlClient();
