import { bool, cleanEnv, num, str, url } from "envalid";

interface Env {
  APP_NAME: string;
  AUTH_URL: string;
  AUTH_CLIENT_ID: string;
  AUTH_CLIENT_SECRET: string;
  DEPLOYMENT_ENVIRONMENT: string;
  GATEWAY_URL: string;
  KAFKA_BOOTSTRAP_SERVERS: string;
  KAFKA_PASSWORD: string;
  KAFKA_SASL_MECHANISM: "plain" | "scram-sha-512";
  KAFKA_SOURCE_TOPIC_NAME: string;
  KAFKA_USERNAME: string;
  LOGGER_LEVEL: string;
  LOG_PAYLOAD_ORDER_NUMBERS: string;
  MISSION_MANAGEMENT_API_URL: string;
  SHOULD_PROCESS_ORDER_CHAINING: boolean;
  TIMEZONE_OFFSET: number;
  USX_DATA_BRIDGE_API_URL: string;
}


export const env: Env = cleanEnv(process.env, {
  APP_NAME: str({
    default: "cuor-order-chaining-consumer",
    devDefault: "cuor-order-chaining-consumer"
  }),
  AUTH_URL: url({
    default: "https://auth.haulynx.io",
    devDefault: "https://auth-dev.haulynx.io"
  }),
  AUTH_CLIENT_ID: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  AUTH_CLIENT_SECRET: str({
    default: "defaultValue",
    devDefault: "defaultValue"
  }),
  DEPLOYMENT_ENVIRONMENT: str({
    default: "prod",
    devDefault: "dev"
  }),
  GATEWAY_URL: url({
    default: "https://gateway.haulynx.io/graphql",
    devDefault: "https://gateway-dev.haulynx.io/graphql"
  }),
  KAFKA_BOOTSTRAP_SERVERS: str({
    default: "pkc-4nym6.us-east-1.aws.confluent.cloud:9092",
    desc: "Comma separated list of kafka broker URLs"
  }),
  KAFKA_PASSWORD: str({
    default: "admin",
    devDefault: "admin"
  }),
  KAFKA_SASL_MECHANISM: str({
    default: "plain",
    devDefault: "plain"
  }),
  KAFKA_SOURCE_TOPIC_NAME: str({
    default: "stage_bus_iohaulynx_usxorder_event_json",
    devDefault: "dev_bus_iohaulynx_usxorder_event_json",
    desc: "Kafka topic name we will be subscribing to"
  }),
  KAFKA_USERNAME: str({
    default: "admin",
    devDefault: "admin"
  }),
  LOG_PAYLOAD_ORDER_NUMBERS: str({
    default: "",
    desc: "Order numbers for which the raw payload should be logged"
  }),
  LOGGER_LEVEL: str({
    default: "error",
    devDefault: "trace",
    desc: "The logging threshold level (default level is 'info'). Choices are 'trace', 'debug', 'info', 'warn', 'error', 'fatal'."
  }),
  MISSION_MANAGEMENT_API_URL: str({
    default: "https://cuor-mission-management-api-prod.internal.ue1.haulynx.io",
    devDefault: "https://cuor-mission-management-api-dev.internal.ue1.haulynx.io"
  }),
  SHOULD_PROCESS_ORDER_CHAINING: bool({
    default: true,
    desc: "Feature flag for related order creation"
  }),
  TIMEZONE_OFFSET: num({
    default: 5,
    desc: "Timezone offset to appointment time"
  }),
  USX_DATA_BRIDGE_API_URL: url({
    default: "https://cuor-usx-data-bridge-api.internal.ue1.haulynx.io",
    devDefault: "https://cuor-usx-data-bridge-api-dev.internal.ue1.haulynx.io"
  })
});
