import { LoadCreationAction } from "@haulynx/entities";
import format from "date-fns-tz/format";
import { TIMEZONE_OFFSET } from "../conifg";

export const buildUsxOrderCreatePayload = (payload: any, loadCreationAction: LoadCreationAction): any => {
  const originEarlyDateTimeEpoch = payload.last_stop.late_appointment_ms + loadCreationAction.originAppointmentTimeOffset * 60000 - TIMEZONE_OFFSET * 60 * 60000; // minus 5 hours to convert to Chattanooga time
  const originLateDateTimeEpoch = originEarlyDateTimeEpoch + loadCreationAction.originAppointmentTimeInterval * 60000;
  const destinationEarlyDateTimeEpoch = originLateDateTimeEpoch + loadCreationAction.destinationAppointmentTimeOffset * 60000;
  const destinationLateDateTimeEpoch = destinationEarlyDateTimeEpoch + loadCreationAction.destinationAppointmentTimeInterval * 60000;

  return {
    auditUser: "XTSYSTEM",
    companyNumber: "01",
    orderDate: format(new Date(), "yyyy-MM-dd"),

    billToCustomerId: Number(loadCreationAction.billTo),
    shipperCustomerId: Number(loadCreationAction.originCustomer),
    consigneeCustomerId: Number(loadCreationAction.destinationCustomer),

    liveLoadDropLoad: "D",
    originLoadType: payload.unload_requirements === "L" ? "L" : "P",

    originEarlyDateTime: formatDateOrderCreatePayload(originEarlyDateTimeEpoch), // YYYY-MM-DD-HH.MM.SS.ssssss - Chattanooga time
    originLoadUnloadTime: "2.0",
    originLateDateTime: formatDateOrderCreatePayload(originLateDateTimeEpoch), // YYYY-MM-DD-HH.MM.SS.ssssss - Chattanooga time
    originAppointmentSet: "Y",

    destinEarlyDateTime: formatDateOrderCreatePayload(destinationEarlyDateTimeEpoch), // YYYY-MM-DD-HH.MM.SS.ssssss - Chattanooga time
    destinLoadUnloadTime: "2.0",
    destinLateDateTime: formatDateOrderCreatePayload(destinationLateDateTimeEpoch), // YYYY-MM-DD-HH.MM.SS.ssssss - Chattanooga time
    destinAppointmentSet: "Y",

    teamRequired: "N",
    teamPayrate: "N",
    driverLoad: "N",
    driverUnload: "N",
    hazmatLoad: "N",
    headerLine: [
      {
        lineType: "LN",
        description: "FAK"
      }
    ]
  };
};

const replaceMidnight = (t: number): number => t % (24 * 60 * 60000) > 59999 ? t : t + (60000 - t % (24 * 60 * 60000));

const formatDateOrderCreatePayload = (epochTime: number): string =>
  new Date(replaceMidnight(epochTime)).toISOString().replace(/T/, "-").replace(/:/g, ".").replace(/Z/, "000");

